detect_host_isa

Function detect_host_isa 

pub fn detect_host_isa() -> u8
Detect the best ISA available on the current host at runtime.

Returns one of the ISA_* constants. Never returns ISA_UNDETECTED.

This function is also used in the unit tests to validate that we always detect a valid ISA on the host machine.