generate

Function generate 

pub fn generate(input: TokenStream) -> Result<TokenStream, Error>
Generate a twiddle codelet for the given radix.

Errors

Returns a syn::Error when the input does not parse as a valid radix literal, or when the radix is not in the supported set {2, 4, 8, 16}.