Module symbolic

Module symbolic 

Symbolic FFT operation representation.

This module provides a symbolic representation of FFT operations that can be optimized through common subexpression elimination (CSE) and strength reduction before code generation.

Note: These types are infrastructure for the codegen proc-macros and are tested but not directly exported (proc-macro crates can only export proc-macro functions).

Structs

ComplexExpr
A complex symbolic expression (real, imaginary pair).
ConstantFolder
Constant folder that applies algebraic simplifications to fixpoint.
StrengthReducer
Strength reduction optimizer.
SymbolicFFT
FFT symbolic computation.

Enums

Expr
A symbolic expression representing FFT operations.

Functions

emit_body_from_symbolic
Build the body TokenStream for one direction of an n-point FFT from symbolic computation and optimization passes.
schedule_instructions
Schedule assignment statements to maximise instruction-level parallelism (ILP).