ConstantFolder

Struct ConstantFolder 

pub struct ConstantFolder;
Constant folder that applies algebraic simplifications to fixpoint.

This wraps StrengthReducer and applies it repeatedly until the expression no longer changes, ensuring all nested constant folding opportunities are caught.

Implementations

Source

impl ConstantFolder

pub fn fold(expr: &Expr) -> Expr

Apply constant folding to an expression until fixpoint.

This applies strength reduction (which includes constant folding rules) repeatedly until the expression stabilizes.