Internal codelet generation logic for OxiFFT.
This crate contains the codelet generation functions used by the
oxifft-codegen proc-macro crate. It is a regular library crate
(not proc-macro = true) so that its functions can be used from
benchmark binaries and integration tests.
All public items in this crate are considered semver-unstable —
they may change at any time. External code should use the proc-macro
interface exposed by oxifft-codegen instead.
Re-exports
pub use gen_any::classify;pub use gen_any::CodegenError;pub use gen_any::CodeletBuilder;pub use gen_any::SizeClass;
Modules
- gen_any
- Dispatch-layer codelet generation for arbitrary user-specified sizes.
- gen_
mixed_ radix - gen_
notw - Non-twiddle codelet generation.
- gen_odd
- Odd-size DFT codelet generation using Winograd minimum-multiply factorizations.
- gen_
rader - Rader prime codelet generation for primes 11 and 13.
- gen_
rdft - RDFT codelet generation — R2HC and HC2R.
- gen_
simd - SIMD codelet generation.
- gen_
twiddle - Twiddle-factor codelet generation.
- symbolic
- Symbolic FFT operation representation.
- winograd_
constants - Mirror of
oxifft::dft::codelets::winograd_constantsfor use by codegen-impl.