Crate oxifft_codegen_impl

Crate oxifft_codegen_impl 

Internal codelet generation logic for OxiFFT.

This crate contains the codelet generation functions used by the oxifft-codegen proc-macro crate. It is a regular library crate (not proc-macro = true) so that its functions can be used from benchmark binaries and integration tests.

All public items in this crate are considered semver-unstable — they may change at any time. External code should use the proc-macro interface exposed by oxifft-codegen instead.

Modules

gen_notw
Non-twiddle codelet generation.
gen_rdft
RDFT codelet generation — R2HC and HC2R.
gen_simd
SIMD codelet generation.
gen_twiddle
Twiddle-factor codelet generation.
symbolic
Symbolic FFT operation representation.