generate_from_macro

Function generate_from_macro 

pub fn generate_from_macro(input: TokenStream) -> Result<TokenStream, Error>
Entry point for the gen_dispatcher_codelet! proc-macro.

Parses size = N, ty = TY and calls generate_dispatcher.

Errors

Returns a syn::Error when the input does not parse as valid key-value pairs, a required key is missing, or size / ty have unsupported values.