Symbolic FFT operation representation.
This module provides a symbolic representation of FFT operations that can be optimized through common subexpression elimination (CSE) and strength reduction before code generation.
Note: These types are infrastructure for the codegen proc-macros and are tested but not directly exported (proc-macro crates can only export proc-macro functions).
Structs
- Complex
Expr - A complex symbolic expression (real, imaginary pair).
- Constant
Folder - Constant folder that applies algebraic simplifications to fixpoint.
- Strength
Reducer - Strength reduction optimizer.
- SymbolicFFT
- FFT symbolic computation.
Enums
- Expr
- A symbolic expression representing FFT operations.
Functions
- emit_
body_ from_ symbolic - Build the body
TokenStreamfor one direction of an n-point FFT from symbolic computation and optimization passes. - schedule_
instructions - Schedule assignment statements to maximise instruction-level parallelism (ILP).